@@ -1,7 +1,5 @@
 package Business::AuthorizeNet::CIM;
-{
-    $Business::AuthorizeNet::CIM::VERSION = '0.08';
-}
+$Business::AuthorizeNet::CIM::VERSION = '0.09';
 
 # ABSTRACT: Authorize.Net Customer Information Manager (CIM) Web Services API
 
@@ -558,6 +556,30 @@ sub getCustomerShippingAddressRequest {
     return $d;
 }
 
+sub getHostedProfilePageRequest {
+    my ( $self, $customerProfileId ) = @_;
+
+    my $xml;
+    my $writer = XML::Writer->new( OUTPUT => \$xml );
+    $writer->startTag( 'getHostedProfilePageRequest',
+        'xmlns' => 'AnetApi/xml/v1/schema/AnetApiSchema.xsd' );
+    $writer->startTag('merchantAuthentication');
+    $writer->dataElement( 'name',           $self->{login} );
+    $writer->dataElement( 'transactionKey', $self->{transactionKey} );
+    $writer->endTag('merchantAuthentication');
+    $writer->dataElement( 'customerProfileId', $customerProfileId );
+    $writer->endTag('getHostedProfilePageRequest');
+
+    $xml = '<?xml version="1.0" encoding="utf-8"?>' . "\n" . $xml;
+    print "<!-- $xml -->\n\n" if $self->{debug};
+    my $resp = $self->{ua}
+      ->post( $self->{url}, Content => $xml, 'Content-Type' => 'text/xml' );
+    print "<!-- " . $resp->content . " -->\n\n" if $self->{debug};
+
+    my $d = XMLin( $resp->content, SuppressEmpty => '' );
+    return $d;
+}
+
 sub updateCustomerProfile {
     my $self = shift;
     my $args = scalar @_ % 2 ? shift : {@_};
@@ -780,13 +802,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Business::AuthorizeNet::CIM - Authorize.Net Customer Information Manager (CIM) Web Services API
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -1115,6 +1139,13 @@ Retrieve a customer shipping address for an existing customer profile.
 
     $cim->getCustomerShippingAddressRequest($customerProfileId, $customerAddressId);
 
+=head3 getHostedProfilePageRequest
+
+Get a token for use in a CIM hosted popup.
+
+    my $result = $cim->getHostedProfilePageRequest($customerProfileId);
+    print $result->{token} if $result->{messages}->{resultCode} eq 'Ok';
+
 =head3 updateCustomerProfile
 
 Update an existing customer profile
@@ -1225,7 +1256,7 @@ Rhesa Rozendaal
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Fayland Lam.
+This software is copyright (c) 2015 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
